@@ -3,6 +3,10 @@ import unicodedata
 from typing import Optional
 
 
+def inline(value: str) -> str:
+    return re.sub(r'\r?\n\s+', ' ', value).strip()
+
+
 def slugify(value: str, allow_unicode: bool = False) -> str:
     if allow_unicode:
         value = unicodedata.normalize('NFKC', str(value))
